PieceBoardState

Struct PieceBoardState 

pub struct PieceBoardState {
    pub p1_pieces: u64,
    pub all_pieces: u64,
    pub elephants: u64,
    pub camels: u64,
    pub horses: u64,
    pub dogs: u64,
    pub cats: u64,
    pub rabbits: u64,
}
A set of bitboards representing the game state. Bits are in the perspective of player 1. Bits are left to right, top to bottom:

  • First bit is the top left square (A8).
  • Second bit is to the right. (B8).
  • Last bit being the bottom right (H1).

Fields

p1_pieces: u64all_pieces: u64elephants: u64camels: u64horses: u64dogs: u64cats: u64rabbits: u64

Implementations

Source

impl PieceBoardState

pub fn bits_for_piece(&self, piece: Piece, p1_pieces: bool) -> u64

Returns the bits for a specific piece type for a specific player.

pub fn player_piece_mask(&self, p1_pieces: bool) -> u64

Returns a bit board where each bit represents a current player’s piece on that square

pub fn bits_by_piece_type(&self, piece: Piece) -> u64

pub fn placement_bit(&self) -> u64

pub fn trapped_piece_bits(&self) -> u64

pub fn piece_type_at_square(&self, square: &Square) -> Option<Piece>